#[repr(u16)]
pub enum StatusCode { OK = 200, MalformedProtocolMessage = 400, UnexpectedProtocolMessage = 401, InvalidRequest = 410, InvalidLastBlock = 411, InvalidUnconfirmedBlock = 412, InvaildDifficultyBoundary = 413, InternalError = 500, Network = 501, }
StatusCodes indicate whether a specific operation has been successfully completed.

The StatusCode element is a 3-digit integer.

The first digest of the StatusCode defines the class of result:

  • 1xx: Informational response – the request was received, continuing process.
  • 2xx: Success - The action requested by the client was received, understood, and accepted.
  • 4xx: Client errors - The error seems to have been caused by the client.
  • 5xx: Server errors - The server failed to fulfil a request.

Variants



OK = 200

OK



MalformedProtocolMessage = 400

Malformed protocol message.



UnexpectedProtocolMessage = 401

Unexpected light-client protocol message.



InvalidRequest = 410

The request data is incorrect.



InvalidLastBlock = 411

The last block sent from client is invalid.



InvalidUnconfirmedBlock = 412

At least one unconfirmed block sent from client is invalid.



InvaildDifficultyBoundary = 413

The difficulty boundary is not in the provided block range.



InternalError = 500

Throws an internal error.



Network = 501

Throws an error from the network.

Implementations

source

impl StatusCode

source

pub fn with_context<S: ToString>(self, context: S) -> Status

Convert a status code into a status which has a context.