#[repr(u16)]pub enum StatusCode {
OK,
MalformedProtocolMessage,
UnexpectedProtocolMessage,
InvalidRequest,
InvalidLastBlock,
InvalidUnconfirmedBlock,
InvaildDifficultyBoundary,
InternalError,
Network,
}Expand description
StatusCodes indicate whether a specific operation has been successfully completed.
The StatusCode element is a 3-digit integer.
The first digest of the StatusCode defines the class of result:
- 1xx: Informational response – the request was received, continuing process.
- 2xx: Success - The action requested by the client was received, understood, and accepted.
- 4xx: Client errors - The error seems to have been caused by the client.
- 5xx: Server errors - The server failed to fulfil a request.
Variants
OK
OK
MalformedProtocolMessage
Malformed protocol message.
UnexpectedProtocolMessage
Unexpected light-client protocol message.
InvalidRequest
The request data is incorrect.
InvalidLastBlock
The last block sent from client is invalid.
InvalidUnconfirmedBlock
At least one unconfirmed block sent from client is invalid.
InvaildDifficultyBoundary
The difficulty boundary is not in the provided block range.
InternalError
Throws an internal error.
Network
Throws an error from the network.
Implementations
sourceimpl StatusCode
impl StatusCode
sourcepub fn with_context<S: ToString>(self, context: S) -> Status
pub fn with_context<S: ToString>(self, context: S) -> Status
Convert a status code into a status which has a context.